session

package
v0.6.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 3, 2026 License: MIT Imports: 14 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type JobInfo

type JobInfo struct {
	Plan      string `json:"plan"`
	Job       string `json:"job"`
	LineIndex int    `json:"lineIndex"`
}

JobInfo holds information about a grove plan job found in the transcript

type Scanner

type Scanner struct{}

Scanner is responsible for finding and parsing session transcript logs.

func NewScanner

func NewScanner() *Scanner

NewScanner creates a new session scanner.

func (*Scanner) Scan

func (s *Scanner) Scan() ([]SessionInfo, error)

Scan searches for and parses all Claude and Codex session logs.

type SessionInfo

type SessionInfo struct {
	SessionID   string    `json:"sessionId"`
	ProjectName string    `json:"projectName"`
	ProjectPath string    `json:"projectPath"`
	Worktree    string    `json:"worktree,omitempty"`
	Ecosystem   string    `json:"ecosystem,omitempty"`
	Jobs        []JobInfo `json:"jobs,omitempty"`
	LogFilePath string    `json:"logFilePath"`
	StartedAt   time.Time `json:"startedAt"`
	Provider    string    `json:"provider,omitempty"` // "claude", "codex", or "opencode"
}

SessionInfo holds structured information about a session transcript

func ResolveSessionInfo

func ResolveSessionInfo(spec string) (*SessionInfo, error)

ResolveSessionInfo finds a session's metadata based on a specifier which can be a plan/job string, a session ID, or a direct file path to a job file or log file. It prioritizes the fastest lookup methods first.

Jump to